diff --git a/AppData/ComLib.cs b/AppData/ComLib.cs
index 237c65c..9d34a2d 100644
--- a/AppData/ComLib.cs
+++ b/AppData/ComLib.cs
@@ -1213,10 +1213,23 @@ namespace AppData
memLayer.ML.setRSV(redNextBunkKey(currBunkId), "");
}
}
+ ///
+ /// Elenco di sheet in lavorazione su una data macchina:
+ /// - da macchina recupera il BATCH
+ /// - dal batch prende i BUNK attivi sulla macchina (posizione 3)
+ /// - filtra i fogli già lavorati
+ ///
+ ///
+ ///
+ public static SheetWorkList prodGetSheetWorkList(string machineName)
+ {
+ SheetWorkList answ = null;
+ return answ;
+ }
///
- /// Restituisce il BUNK che è il primo della lissta:
- /// - posizione = 5 (ho letto da webApp il BUNK e preso in carico)
+ /// Restituisce il BUNK che è il primo della lista:
+ /// - posizione = 3 (ho letto da webApp il BUNK e preso in carico)
/// - NumSheet > NumSheetUnload
/// - Ordinato per StackIndex (crescente) x avere il più VECCHIO
///
diff --git a/NKC_SDK/Objects.cs b/NKC_SDK/Objects.cs
index 4039584..fff3b35 100644
--- a/NKC_SDK/Objects.cs
+++ b/NKC_SDK/Objects.cs
@@ -525,6 +525,16 @@ namespace NKC_SDK
}
}
}
+ ///
+ /// Estensione classe sheet comprensiva di BunkId
+ ///
+ public class ProdSheetExt: ProdSheet
+ {
+ ///
+ /// Identificativo univoco BUNK / Stack
+ ///
+ public int BunkId { get; set; }
+ }
///
/// Singolo Pannello IN LAVORAZIONE
@@ -558,13 +568,42 @@ namespace NKC_SDK
}
+
+ ///
+ /// Classe che rappresenta un insieme di Sheet da lavorare (contenuti in 1 o + bunk)
+ ///
+ public class SheetWorkList
+ {
+ ///
+ /// Elenco dei pannelli (sheets) in lavorazione
+ ///
+ public List SheetList { get; set; }
+ ///
+ /// Numero di Sheets da lavorare
+ ///
+ public int NumSheets
+ {
+ get
+ {
+ int answ = 0;
+ try
+ {
+ answ = SheetList.Count;
+ }
+ catch
+ { }
+ return answ;
+ }
+ }
+ }
+
///
/// Classe che rappresenta i BUNK da lavorare
///
public class ProdBunk
{
///
/// Identificativo univoco stack
///
public int BunkId { get; set; }
///
@@ -572,11 +611,11 @@ namespace NKC_SDK
///
public CStatus Status { get; set; }
///
/// Codice dataMAtrix dello stack
///
public string DataMatrix { get; set; }
///
/// Data inizio processing dello Stack
///
public DateTime DtStart { get; set; }
///
@@ -558,13 +568,42 @@ namespace NKC_SDK
{
///
- /// Identificativo univoco stack
+ /// Identificativo univoco BUNK / Stack
///
public int BunkId { get; set; }
@@ -572,11 +611,11 @@ namespace NKC_SDK
public CStatus Status { get; set; }
///
- /// Codice dataMAtrix dello stack
+ /// Codice dataMatrix del BUNK
///
public string DataMatrix { get; set; }
@@ -572,11 +611,11 @@ namespace NKC_SDK
public string DataMatrix { get; set; }
///
- /// Data inizio processing dello Stack
+ /// Data inizio processing del BUNK
///
public DateTime DtStart { get; set; }